==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkDemandDrivenPipeline.java <==
// java wrapper for vtkDemandDrivenPipeline object
//

package vtk;
import vtk.*;

public class vtkDemandDrivenPipeline extends vtkExecutive
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int Update_2();
  public int Update()
    { return Update_2(); }

  private native int Update_3(int id0);
  public int Update(int id0)
    { return Update_3(id0); }

  private native int GetPipelineMTime_4();
  public int GetPipelineMTime()
    { return GetPipelineMTime_4(); }

  private native int SetReleaseDataFlag_5(int id0,int id1);
  public int SetReleaseDataFlag(int id0,int id1)
    { return SetReleaseDataFlag_5(id0,id1); }

  private native int GetReleaseDataFlag_6(int id0);
  public int GetReleaseDataFlag(int id0)
    { return GetReleaseDataFlag_6(id0); }

  private native int UpdatePipelineMTime_7();
  public int UpdatePipelineMTime()
    { return UpdatePipelineMTime_7(); }

  private native int UpdateDataObject_8();
  public int UpdateDataObject()
    { return UpdateDataObject_8(); }

  private native int UpdateInformation_9();
  public int UpdateInformation()
    { return UpdateInformation_9(); }

  private native int UpdateData_10(int id0);
  public int UpdateData(int id0)
    { return UpdateData_10(id0); }

  private native long REQUEST_DATA_OBJECT_11();
  public vtkInformationRequestKey REQUEST_DATA_OBJECT() {
    long temp = REQUEST_DATA_OBJECT_11();

    if (temp == 0) return null;
    return (vtkInformationRequestKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long REQUEST_INFORMATION_12();
  public vtkInformationRequestKey REQUEST_INFORMATION() {
    long temp = REQUEST_INFORMATION_12();

    if (temp == 0) return null;
    return (vtkInformationRequestKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long REQUEST_DATA_13();
  public vtkInformationRequestKey REQUEST_DATA() {
    long temp = REQUEST_DATA_13();

    if (temp == 0) return null;
    return (vtkInformationRequestKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long REQUEST_DATA_NOT_GENERATED_14();
  public vtkInformationRequestKey REQUEST_DATA_NOT_GENERATED() {
    long temp = REQUEST_DATA_NOT_GENERATED_14();

    if (temp == 0) return null;
    return (vtkInformationRequestKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long RELEASE_DATA_15();
  public vtkInformationIntegerKey RELEASE_DATA() {
    long temp = RELEASE_DATA_15();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long DATA_NOT_GENERATED_16();
  public vtkInformationIntegerKey DATA_NOT_GENERATED() {
    long temp = DATA_NOT_GENERATED_16();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long NewDataObject_17(String id0);
  public vtkDataObject NewDataObject(String id0) {
    long temp = NewDataObject_17(id0);

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  public vtkDemandDrivenPipeline() { super(); }

  public vtkDemandDrivenPipeline(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-3-armv6h.pkg.tar.xz: vtk/vtkDemandDrivenPipeline.java <==
// java wrapper for vtkDemandDrivenPipeline object
//

package vtk;
import vtk.*;

public class vtkDemandDrivenPipeline extends vtkExecutive
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int Update_2();
  public int Update()
    { return Update_2(); }

  private native int Update_3(int id0);
  public int Update(int id0)
    { return Update_3(id0); }

  private native int GetPipelineMTime_4();
  public int GetPipelineMTime()
    { return GetPipelineMTime_4(); }

  private native int SetReleaseDataFlag_5(int id0,int id1);
  public int SetReleaseDataFlag(int id0,int id1)
    { return SetReleaseDataFlag_5(id0,id1); }

  private native int GetReleaseDataFlag_6(int id0);
  public int GetReleaseDataFlag(int id0)
    { return GetReleaseDataFlag_6(id0); }

  private native int UpdatePipelineMTime_7();
  public int UpdatePipelineMTime()
    { return UpdatePipelineMTime_7(); }

  private native int UpdateDataObject_8();
  public int UpdateDataObject()
    { return UpdateDataObject_8(); }

  private native int UpdateInformation_9();
  public int UpdateInformation()
    { return UpdateInformation_9(); }

  private native int UpdateData_10(int id0);
  public int UpdateData(int id0)
    { return UpdateData_10(id0); }

  private native long REQUEST_DATA_OBJECT_11();
  public vtkInformationRequestKey REQUEST_DATA_OBJECT() {
    long temp = REQUEST_DATA_OBJECT_11();

    if (temp == 0) return null;
    return (vtkInformationRequestKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long REQUEST_INFORMATION_12();
  public vtkInformationRequestKey REQUEST_INFORMATION() {
    long temp = REQUEST_INFORMATION_12();

    if (temp == 0) return null;
    return (vtkInformationRequestKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long REQUEST_DATA_13();
  public vtkInformationRequestKey REQUEST_DATA() {
    long temp = REQUEST_DATA_13();

    if (temp == 0) return null;
    return (vtkInformationRequestKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long REQUEST_DATA_NOT_GENERATED_14();
  public vtkInformationRequestKey REQUEST_DATA_NOT_GENERATED() {
    long temp = REQUEST_DATA_NOT_GENERATED_14();

    if (temp == 0) return null;
    return (vtkInformationRequestKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long RELEASE_DATA_15();
  public vtkInformationIntegerKey RELEASE_DATA() {
    long temp = RELEASE_DATA_15();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long DATA_NOT_GENERATED_16();
  public vtkInformationIntegerKey DATA_NOT_GENERATED() {
    long temp = DATA_NOT_GENERATED_16();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long NewDataObject_17(String id0);
  public vtkDataObject NewDataObject(String id0) {
    long temp = NewDataObject_17(id0);

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkDemandDrivenPipeline() { super(); }

  public vtkDemandDrivenPipeline(long id) { super(id); }
  public native long   VTKInit();

}
